// @APIVersion 1.0.0
// @Title beego Test API
// @Description beego has a very cool tools to autogenerate documents for your API
// @Contact astaxie@gmail.com
// @TermsOfServiceUrl http://beego.me/
// @License Apache 2.0
// @LicenseUrl http://www.apache.org/licenses/LICENSE-2.0.html
package routers

import (
	"github.com/beego/beego/v2/server/web"
	"github.com/beego/beego/v2/server/web/filter/cors"
	"hongze/hongze_web_mfyx/controllers"
)

func init() {
	web.InsertFilter("*", web.BeforeRouter, cors.Allow(&cors.Options{
		AllowAllOrigins:  true,
		AllowMethods:     []string{"GET", "POST", "PUT", "DELETE", "OPTIONS"},
		AllowHeaders:     []string{"Origin", "Account", "Authorization", "Access-Control-Allow-Origin", "Access-Control-Allow-Headers", "Content-Type", "From"},
		ExposeHeaders:    []string{"Content-Length", "Access-Control-Allow-Origin", "Access-Control-Allow-Headers", "Content-Type", "Sign"},
		AllowCredentials: true,
	}))

	ns := web.NewNamespace("/api",
		web.NSNamespace("/wechat",
			web.NSInclude(
				&controllers.WechatController{},
				&controllers.WechatCommonController{},
				&controllers.MobileWechatController{},
			),
		),
		web.NSNamespace("/user",
			web.NSInclude(
				&controllers.UserController{},
				&controllers.UserCommonController{},
			),
		),
		web.NSNamespace("/permission",
			web.NSInclude(
				&controllers.ChartPermissionController{},
				&controllers.ChartPermissionAuthController{},
				&controllers.MobileChartPermissionAuthController{},
			),
		),
		web.NSNamespace("/resource",
			web.NSInclude(
				&controllers.BaseResourceController{},
			),
			web.NSInclude(
				&controllers.ResourceController{},
			),
		),
		web.NSNamespace("/home",
			web.NSInclude(
				&controllers.MobileHomeController{},
			),
		),
		web.NSNamespace("/article",
			web.NSInclude(
				&controllers.ArticleController{},
				&controllers.ArticleNoLoginController{},
			),
		),
		web.NSNamespace("/search",
			web.NSInclude(
				&controllers.MobileSearchController{},
				&controllers.BaseSearchController{},
			),
		),
		web.NSNamespace("/report",
			web.NSInclude(
				&controllers.ReportController{},
				&controllers.ReportCommonController{},
				&controllers.MobileReportController{},
			),
		),
		web.NSNamespace("/report_billboard",
			web.NSInclude(
				&controllers.ReportBillboardController{},
				&controllers.ReportBillboardCommonController{},
				&controllers.MobileReportBillboardController{},
			),
		),
		web.NSNamespace("/micro_roadshow",
			web.NSInclude(
				&controllers.MicroRoadShowController{},
			),
		),
		web.NSNamespace("/activity",
			web.NSInclude(
				&controllers.ActivityController{},
				&controllers.ActivityNoLoginController{},
			),
		),

		web.NSNamespace("/advice",
			web.NSInclude(
				&controllers.AdviceController{},
			),
		),
		web.NSNamespace("/research",
			web.NSInclude(
				&controllers.MobileResearchController{},
			),
		),

		web.NSNamespace("/config",
			web.NSInclude(
				&controllers.ConfigController{},
				&controllers.BaseConfigController{},
			),
		),
		web.NSNamespace("/banner",
			web.NSInclude(
				&controllers.BannerController{},
				&controllers.BaseBannerController{},
			),
		),
		web.NSNamespace("/tag",
			web.NSInclude(
				&controllers.TagController{},
				&controllers.BaseTagController{},
			),
		),
		web.NSNamespace("/collection",
			web.NSInclude(
				&controllers.CollectionController{},
				&controllers.BaseCollectionController{},
			),
		),
		web.NSNamespace("/yanxuan_special",
			web.NSInclude(
				&controllers.YanxuanSpecialController{},
				&controllers.YanxuanSpecialNoLoginController{},
				&controllers.YanxuanSpecialMessageController{},
			),
		),
		web.NSNamespace("/order",
			web.NSInclude(
				&controllers.OrderController{},
			),
		),
	)
	web.AddNamespace(ns)
}
