package services

import (
	"github.com/aliyun/aliyun-oss-go-sdk/oss"
	"os"
	"time"

	"hongze/hongze_web_mfyx/utils"
)

// 图片上传到阿里云
func UploadAliyun(filename, filepath string) (string, error) {
	client, err := oss.New(utils.Endpoint, utils.AccessKeyId, utils.AccessKeySecret)
	if err != nil {
		return "1", err
	}
	bucket, err := client.Bucket(utils.Bucketname)
	if err != nil {
		return "2", err
	}
	path := utils.Upload_dir + time.Now().Format("200601/20060102/")
	path += filename
	err = bucket.PutObjectFromFile(path, filepath)
	if err != nil {
		return "3", err
	}
	path = utils.Imghost + path
	return path, err
}

// 音频上传到阿里云
func UploadAudioAliyun(filename, filepath string) (string, error) {
	client, err := oss.New(utils.Endpoint, utils.AccessKeyId, utils.AccessKeySecret)
	if err != nil {
		return "1", err
	}
	bucket, err := client.Bucket(utils.Bucketname)
	if err != nil {
		return "2", err
	}
	path := utils.Upload_Audio_Dir + time.Now().Format("200601/20060102/")
	path += filename
	err = bucket.PutObjectFromFile(path, filepath)
	if err != nil {
		return "3", err
	}
	path = utils.Imghost + path
	return path, err
}

// 视频上传到阿里云
func UploadVideoAliyun(filename, filepath, savePath string) error {
	defer func() {
		os.Remove(filepath)
	}()
	client, err := oss.New(utils.Endpoint, utils.AccessKeyId, utils.AccessKeySecret)
	if err != nil {
		return err
	}
	bucket, err := client.Bucket(utils.Bucketname)
	if err != nil {
		return err
	}
	//path := utils.Upload_Audio_Dir + time.Now().Format("200601/20060102/")
	//path += filename
	err = bucket.PutObjectFromFile(savePath, filepath)
	if err != nil {
		return err
	}
	//path = utils.Imghost + path
	//return path,err
	return err
}

// PDF上传到阿里云
func UploadPdfAliyun(filename, filepath string) (string, error) {
	client, err := oss.New(utils.Endpoint, utils.AccessKeyId, utils.AccessKeySecret)
	if err != nil {
		return "1", err
	}
	bucket, err := client.Bucket(utils.Bucketname)
	if err != nil {
		return "2", err
	}
	path := utils.Upload_Pdf_Dir + time.Now().Format("200601/20060102/")
	path += filename
	err = bucket.PutObjectFromFile(path, filepath)
	if err != nil {
		return "3", err
	}
	path = utils.Imghost + path
	return path, err
}

const (
	HzEndpoint          = "oss-cn-shanghai.aliyuncs.com"
	HzBucketName string = "hzchart"
)

// 上传文件到阿里云
func UploadFileToAliyun(filename, filepath, savePath string) error {
	defer func() {
		os.Remove(filepath)
	}()
	client, err := oss.New(HzEndpoint, utils.AccessKeyId, utils.AccessKeySecret)
	if err != nil {
		return err
	}
	bucket, err := client.Bucket(HzBucketName)
	if err != nil {
		return err
	}
	//path := utils.Upload_Audio_Dir + time.Now().Format("200601/20060102/")
	//path += filename
	err = bucket.PutObjectFromFile(savePath, filepath)
	if err != nil {
		return err
	}
	//path = utils.Imghost + path
	//return path,err
	return err
}

// GetCloudDiskResourceFileTypeExtMap 常见文件类型图标
func GetCloudDiskResourceFileTypeExtMap() map[string]string {
	return map[string]string{
		".doc":  "https://hzstatic.hzinsights.com/static/icon/file_type_docx.png",
		".docx": "https://hzstatic.hzinsights.com/static/icon/file_type_docx.png",

		".pdf": "https://hzstatic.hzinsights.com/static/icon/file_type_pdf.png",

		".ppt":  "https://hzstatic.hzinsights.com/static/icon/file_type_ppt.png",
		".pptx": "https://hzstatic.hzinsights.com/static/icon/file_type_ppt.png",

		".xls":  "https://hzstatic.hzinsights.com/static/icon/file_type_xlsx.png",
		".xlsx": "https://hzstatic.hzinsights.com/static/icon/file_type_xlsx.png",

		".jpg":  "https://hzstatic.hzinsights.com/static/icon/file_type_pic.png",
		".jpeg": "https://hzstatic.hzinsights.com/static/icon/file_type_pic.png",
		".png":  "https://hzstatic.hzinsights.com/static/icon/file_type_pic.png",
		".bmp":  "https://hzstatic.hzinsights.com/static/icon/file_type_pic.png",
		".svg":  "https://hzstatic.hzinsights.com/static/icon/file_type_pic.png",
		".gif":  "https://hzstatic.hzinsights.com/static/icon/file_type_pic.png",

		".mp4":  "https://hzstatic.hzinsights.com/static/icon/file_type_video.png",
		".wmv":  "https://hzstatic.hzinsights.com/static/icon/file_type_video.png",
		".mov":  "https://hzstatic.hzinsights.com/static/icon/file_type_video.png",
		".mpeg": "https://hzstatic.hzinsights.com/static/icon/file_type_video.png",
		".avi":  "https://hzstatic.hzinsights.com/static/icon/file_type_video.png",
		".flv":  "https://hzstatic.hzinsights.com/static/icon/file_type_video.png",
		".rm":   "https://hzstatic.hzinsights.com/static/icon/file_type_video.png",
		".rmvb": "https://hzstatic.hzinsights.com/static/icon/file_type_video.png",

		".mp3": "https://hzstatic.hzinsights.com/static/icon/file_type_audio.png",
		".wma": "https://hzstatic.hzinsights.com/static/icon/file_type_audio.png",
	}
}
